@@ -121,7 +121,6 @@ sub _request {
     }
 
     $uri->query_form($params);
-    print "REQUESTING " . $uri->as_string . "\n";
 
     my $req = HTTP::Request->new(
         $req_method,
@@ -145,8 +144,6 @@ sub _request {
         my $json_coder = JSON::XS->new->ascii->allow_nonref;
         my $req_body = $json_coder->encode($req_body_hash);
         $req->content($req_body);
-
-        print "REQ BODY $req_body\n";
     }
 
     my $response = $self->ua->request($req);
@@ -154,11 +151,6 @@ sub _request {
     if($response->content) {
         $json = JSON::XS->new->utf8->decode($response->content);
 
-        #TEMPORARY
-        my $coder = JSON::XS->new->ascii->pretty->allow_nonref;
-        my $pretty_printed_unencoded = $coder->encode ($json);
-        print "$pretty_printed_unencoded\n";
-
         #die with DigitalOcean::Error
         if($response->code < 200 or $response->code >= 300) {
             my $do_error = DigitalOcean::Error->new(
@@ -191,8 +183,6 @@ sub _request {
 
             #if actions array is present and we are supposed to wait on events, then wait!
             if($json->{links}->{actions} and ($self->wait_on_actions or $wait_on_action)) { 
-                print "WAITING on ACTION in request\n";
-
                 #wait on each returned action that occurred from the API call
                 for my $act_temp (@{$json->{links}->{actions}}) { 
                     my $action = $self->action($act_temp->{id});
@@ -522,7 +512,7 @@ DigitalOcean - An OO interface to the Digital Ocean API (v2).
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 METHODS
 
@@ -1078,7 +1068,7 @@ Adam Hopkins <srchulo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Adam Hopkins.
+This software is copyright (c) 2016 by Adam Hopkins.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
